LogSearchOptions class

Constructors

LogSearchOptions({required String keyword, bool useRegex = false, bool caseSensitive = false, TimeRange? timeRange, LogLevel? logLevel, List<PDLogFile>? files, int maxFileSizeBytes = 10 * 1024 * 1024, int maxResults = 1000, int contextLines = 0})
const

Properties

caseSensitive bool
final
contextLines int
final
files List<PDLogFile>?
final
hashCode int
The hash code for this object.
no setterinherited
keyword String
final
logLevel LogLevel?
final
maxFileSizeBytes int
final
maxResults int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeRange TimeRange?
final
useRegex bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited