LogSearchResult class

日志搜索结果条目,代表一条匹配的日志记录。

Constructors

LogSearchResult({required String filePath, required int lineNumber, required String lineContent, required int matchStart, required int matchLength, DateTime? timestamp, LogLevel? level, String? tag, List<String>? contextBefore, List<String>? contextAfter})
const

Properties

contextAfter List<String>?
final
contextBefore List<String>?
final
filePath String
final
hashCode int
The hash code for this object.
no setterinherited
level LogLevel?
final
lineContent String
final
lineNumber int
final
matchLength int
final
matchStart int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String?
final
timestamp DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited