LogSearchSummary class
日志搜索汇总结果,包含所有匹配条目和统计信息。
Constructors
-
LogSearchSummary({required List<
LogSearchResult> results, required int totalFilesSearched, required int filesWithMatches, required int totalMatches, required int durationMs, required bool reachedMaxResults}) -
const
Properties
- durationMs → int
-
final
- filesWithMatches → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- reachedMaxResults → bool
-
final
-
results
→ List<
LogSearchResult> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalFilesSearched → int
-
final
- totalMatches → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited